package com.fuzamei.web;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.net.URLEncoder;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import com.alibaba.fastjson.JSON;
import com.fuzamei.constant.HintMSG;
import com.fuzamei.constant.Role;
import com.fuzamei.entity.BusinessCheck;
import com.fuzamei.entity.CapitalTransfer;
import com.fuzamei.entity.CapitalTransferCheck;
import com.fuzamei.entity.UserDetail;
import com.fuzamei.service.CapitalTransferService;
import com.fuzamei.service.UserAuthoricationService;
import com.fuzamei.utils.JSONUtil;
import com.fuzamei.utils.PageDTO;
import com.fuzamei.utils.ValidationUtil;

@Controller
@RequestMapping(value = "CapitalTransfer")
public class CapitalTransferAction {
	@Autowired	
	private CapitalTransferService capitalTransferService;
	@Autowired
	private UserAuthoricationService userAuthoricationService;//参数校验  权限授权
	private static final int ROW_NUM = 10; // 分页每页显示数据的数量
	 /**  
     *  查询资金划转表  省分行托管中心指令业务岗
     * @param  
     * @param   
     * @throws Exception  
     */
/*	@RequestMapping(value = "/selectCapitalTransfer", method = RequestMethod.POST)
	@ResponseBody
	public Map<String, Object> selectCapitalTransfer(@RequestBody String data) {
        //System.out.println("查询资金划转列表数据");
		Map<String, Object> mapResult = new LinkedHashMap<String, Object>();
		Map<String, Object> map = JSONUtil.jsonToMap(data);
		PageDTO pageDto=capitalTransferService.selectCapitalTransferTable(map);
		mapResult = JSONUtil.getJsonMap(200, true, "操作成功", pageDto);

		return mapResult;
	}*/
	/**
	 * 各个岗位查看资金划转记录列表
	 * @param data
	 * @return
	 */
	@RequestMapping(value = "/selectCapitalTransfer", method = RequestMethod.POST)
	@ResponseBody
	public Map<String, Object> selectCapitalTransfer(@RequestBody String data) {
        //System.out.println("查询资金划转列表数据");
		try {
			@SuppressWarnings("unchecked")
			Map<String, Object> map = JSON.parseObject(data,Map.class);//将前端传过来的json数据转化为map对象，并将map对象传入service层进行数据校验
			int userId=ValidationUtil.checkAndAssignInt("userId");//首先校验用户权限问题
			UserDetail userDetail = userAuthoricationService.checkUserAuthority(userId,Role.BUSINESS_CHIEF_POS_OF_PBBTBC,Role.BUSINESS_CHECK_POS_OF_PBBTBC,Role.BUSINESS_TRAN_POS_OF_PBBTBC);
			int page = ValidationUtil.checkMinAndAssignInt(map.get("page"), 1); 
			String fund_name=ValidationUtil.checkBlankStringAndAssignEmptyIfIsBlank(map.get("fund_name"));
			String status_name=ValidationUtil.checkBlankStringAndAssignEmptyIfIsBlank(map.get("status_name"));
			long startTime = ValidationUtil.checkAndAssignDefaultLong(map.get("startTime"), 0L); 					//开始时间默认0
			long endTime = ValidationUtil.checkAndAssignDefaultLong(map.get("endTime"), Long.MAX_VALUE); 			//结束时间默认Long最大值
			
			Map<String, Object> mapToService = new LinkedHashMap<String, Object>();
			mapToService.put("userDetail", userDetail);
			mapToService.put("startPage", (page - 1) * ROW_NUM);
			mapToService.put("fund_name", fund_name);
			mapToService.put("status_name", status_name);
			//如果时间顺序错位，要重新进行排位
			mapToService.put("startTime", startTime);
			if (startTime <= endTime) {
				mapToService.put("endTime", endTime);
			} else {
				mapToService.put("endTime", Long.MAX_VALUE);
			}
			mapToService.put("rowNum", ROW_NUM); // 默认每页显示数据是10条，可根据需求修改分页数量
			PageDTO pageDto=capitalTransferService.selectCapitalTransferTableAll(mapToService);
			return JSONUtil.getJsonMap(200, true, HintMSG.QUERY_SUCCESS, pageDto);
		} catch (Exception e) {
			return JSONUtil.getJsonMap(500, false, HintMSG.QUERY_FAIL+":"+e.getMessage(), null);
		}
	}
	/**
	 * 审核记录的查询，当用户点击查看按钮后，不仅显示了资金划转的信息，还显示了资金划转审核记录的信息，这里资金划转的信息直接从前端获取，审核记录根据前端提供的id号>fund_id来进行查询
	 * @param data
	 * @return
	 *         {
				"fund_id":"1012",
				"userId":"xxx"
				}
	 */
	@RequestMapping(value="/queryCapitalTransferCheckInformation",method=RequestMethod.POST)
	@ResponseBody
	private Map<String,Object> queryCapitalTransferCheckInformation(@RequestBody String data){
		try {
			@SuppressWarnings("unchecked")
			Map<String, Object> map = JSON.parseObject(data, Map.class);		//将前端传过来的json数据转化为map对象，并将map对象传入service层进行数据校验
			//首先校验用户权限问题
			int userId=ValidationUtil.checkAndAssignInt(map.get("userId"));
			//查看用户非空和权限(只有【指令业务岗,核算岗和主管岗】有这个权限操作)
			UserDetail userDetail = userAuthoricationService.checkUserAuthority(userId,Role.BUSINESS_CHIEF_POS_OF_PBBTBC,Role.BUSINESS_CHECK_POS_OF_PBBTBC,Role.BUSINESS_TRAN_POS_OF_PBBTBC);
			Integer fund_id =ValidationUtil.checkAndAssignInt(map.get("fund_id"));		//被审核的业务id号需要先被进行校验
			Map<String, Object> mapToService = new LinkedHashMap<String, Object>();
			mapToService.put("userDetail", userDetail);
			mapToService.put("fund_id", fund_id);                        //待待
			List<CapitalTransferCheck> capitalTransferCheckList =capitalTransferService.queryCapitalTransferCheckInformation(mapToService);
			return JSONUtil.getJsonMap(200, true, HintMSG.QUERY_SUCCESS, capitalTransferCheckList);
		} catch (Exception e) {
			return JSONUtil.getJsonMap(500, false, HintMSG.QUERY_FAIL+":"+e.getMessage(), null);
		}
	}
	/**{ 
	    "fund_id":"1002"   postman 传id
       }   暂不用上面代替了
	 * 资金划转列表点击查看详情
	 * @param data
	 * @return
	 */
	@RequestMapping(value="/selectChaKanZiJinHuaZhuan",method=RequestMethod.POST)
	@ResponseBody
	public Map<String,Object> selectChaKanZiJinHuaZhuan(@RequestBody String data){
		//System.out.println("查看资金划转详情信息....");
		Map<String, Object> map = JSONUtil.jsonToMap(data);		//将前端传过来的json数据转化为map对象，并将map对象传入service层进行数据校验
		Map<String, Object> map2= capitalTransferService.selectChaKanZiJinHuaZhuan(map);
		return JSONUtil.getJsonMap(200, true, "操作成功", map2);
		
	}
	/**  
	 * 资金划转下载 doc文档
	 * @param request  
	 * @param response  
	 * @throws Exception  
	 */  
	@RequestMapping(value="/downloadCapitalFile")  
	@ResponseBody 
	public Map<String,Object> downloadCapitalFile(HttpServletRequest request,HttpServletResponse response,@RequestParam("url") String url) throws Exception{  
	    try {
	    	  //模拟文件，456.doc为需要下载的文件  
	        String fileName = request.getSession().getServletContext().getRealPath("")+url;  
	        //获取输入流  
	        InputStream bis = new BufferedInputStream(new FileInputStream(new File(fileName))); 
	        //截取文件名字
	        String filename = url.substring(url.lastIndexOf("/")+1);
	        //转码，免得文件名中文乱码  
	        filename = URLEncoder.encode(filename,"UTF-8");  
	        //设置文件下载头  
	        response.addHeader("Content-Disposition", "attachment;filename=" + filename);    
	        //1.设置文件ContentType类型，这样设置，会自动判断下载文件类型    
	        response.setContentType("multipart/form-data");   
	        BufferedOutputStream out = new BufferedOutputStream(response.getOutputStream());  
	        int len = 0;  
	        while((len = bis.read()) != -1){  
	            out.write(len);  
	            out.flush();  
	        }  
	        out.close();
	        bis.close();
	        //返给前端map进行前端提示
	    	return JSONUtil.getJsonMap(200, true, "下载成功",null); 
			
		} catch (Exception e) {
			return JSONUtil.getJsonMap(500, false, "下载失败:"+e.getMessage(),null); 
		}
	} 
	/**
	 * 由管理人发起划款资金
	 * @param data
	 * @return
	 */
	@PostMapping(value="/insertCapitalTransfer")
	@ResponseBody
	public Map<String,Object> insertCapitalTransfer(  ){
		
		
		
		
		
		
		
		
		return JSONUtil.getJsonMap(200, true, "划款成功", null);
	}
	
	
	
	/**
	 * 划转资金审核的意见提交
	 * @param data
	 * @return
	 * @return Map<String,Object>返回类型
	 * 
	 */
	@RequestMapping(value="/insertCheckTransfer",method=RequestMethod.POST)
	@ResponseBody
	public Map<String,Object> insertCheckTransfer(@RequestBody String data){
		
		try {
			//System.out.println("添加到划转审核总表信息....");
			Map<String, Object> map = JSONUtil.jsonToMap(data);		//将前端传过来的json数据转化为map对象，并将map对象传入service层进行数据校验
			
			return JSONUtil.getJsonMap(200, true, "添加审核意见成功", null);
		} catch (Exception e) {
			return JSONUtil.getJsonMap(500, false, "添加审核意见失败："+e.getMessage(), null);
		}
		
	}
	
	
	
}
